@@ -10,6 +10,7 @@ use crate::{
         declaration_no_important::declaration_no_important,
         font_family_no_duplicate_names::font_family_no_duplicate_names,
         keyframe_declaration_no_important::keyframe_declaration_no_important,
+        no_duplicate_at_import_rules::no_duplicate_at_import_rules,
         no_empty_source::no_empty_source,
         no_invalid_position_at_import_rule::no_invalid_position_at_import_rule,
         selector_max_class::selector_max_class, selector_max_combinators::selector_max_combinators,
@@ -26,6 +27,7 @@ pub mod custom_property_no_missing_var_function;
 pub mod declaration_no_important;
 pub mod font_family_no_duplicate_names;
 pub mod keyframe_declaration_no_important;
+pub mod no_duplicate_at_import_rules;
 pub mod no_empty_source;
 pub mod no_invalid_position_at_import_rule;
 pub mod selector_max_class;
@@ -57,6 +59,7 @@ pub fn get_rules(
         selector_max_combinators((&rules_config.selector_max_combinators).into()),
         font_family_no_duplicate_names((&rules_config.font_family_no_duplicate_names).into())?,
         color_hex_alpha((&rules_config.color_hex_alpha).into()),
+        no_duplicate_at_import_rules((&rules_config.no_duplicate_at_import_rules).into()),
         custom_property_no_missing_var_function(
             (&rules_config.custom_property_no_missing_var_function).into(),
         ),
